####################################
####    t-test Blinded SSR Data  ###
####################################

pilotSize = 100 #Size of Pilot Study
mean1 = 0 #Group 1 Mean
mean2 = 0.2 #Group 2 Mean
stDev = 1 #Common Within-Group Standard Deviation
groupProp = 0.5 #Allocation Proportion to Group 1

group1t = rnorm(round(pilotSize*groupProp),mean1,stDev) #Simulate Group 1 Internal Pilot Data
group2t = rnorm(round(pilotSize*groupProp),mean2,stDev) #Simulate Group 2 Internal Pilot Data

pilotResult = c(group1t,group2t) #Overall Internal Pilot Data
 
pilotSD = sd(pilotResult)
pilotSD #Check overall standard deviation of internal pilot

write.csv(pilotResult,"C:/ttestInternalPilot.csv") #Save data, change file location as needed

####################################
####  Poisson Blinded SSR Data   ###
####################################

pilotSize = 100 #Size of Pilot Study
rate1 = 1 #Group 1 Mean
rate2 = 1.5 #Group 2 Mean
overdisp = 2 #Overdispersion Parameter
groupProp = 0.5 #Allocation Proportion to Group 1

#Function to simulate quasi-Poisson Overdispersed data
rqpois <- function(n, mu, theta) {
  rnbinom(n = n, mu = mu, size = mu/(theta-1))
}

#Simulate Poisson Data without Overdispersion
group1Pois = rpois(round(pilotSize*groupProp),rate1) #Simulate Group 1 Internal Pilot Data w/o Dispersion
group2Pois = rpois(round(pilotSize*groupProp),rate2) #Simulate Group 2 Internal Pilot Data w/o Dispersion

#Simulate Overdispersed Poisson Data
group1Qpois = rqpois(round(pilotSize*groupProp),rate1,overdisp) #Simulate Group 1 Internal Pilot Data w/ Dispersion
group2Qpois = rqpois(round(pilotSize*groupProp),rate2,overdisp) #Simulate Group 2 Internal Pilot Data w/ Dispersion

pilotResultPois = c(group1Pois,group2Pois) #Overall Internal Pilot Data
pilotResultQpois = c(group1Qpois,group2Qpois) #Overall Internal Pilot Data

#Checks
pilotMeanPois = mean(pilotResultPois) #Mean Rate
pilotVarPois = var(pilotResultPois) #Variance of Rates (w/o Dispersion E[X] = Var[X])
pilotVarPois/pilotMeanPois #Overdispersion Estimate

pilotMeanQpois = mean(pilotResultQpois) #Mean Rate
pilotVarQpois = var(pilotResultQpois) #Variance of Rates
pilotVarQpois/pilotMeanQpois #Overdispersion - expect same as overdisp specified (closer w/ higher N)

write.csv(pilotResult,"C:/PoissonInternalPilot.csv") #Save data, change file location as needed
